rendering time 1h 21' 05''

// Photons are off. Test possible with dummy instead of stela (see end of file).






#version 3.6;

#include "functions.inc"

global_settings {
     assumed_gamma 1.0
     max_trace_level 24
     
     #declare Photons = off;
     #if (Photons)          
          photons {
               spacing 0.0015               
          }
     #end
}

// --------------- CAM ---------------------

camera {
     location  <0.0, 1.5, -4.0>
     direction 1.5*z
     right     x*image_width/image_height
     look_at   <0.5, 0.0,  0.0>
}


// ---------------- Lights ----------------


// left spot
light_source {
     0                     
     color rgb 1       
     spotlight               
     translate <-25, 20, -5> 
     translate <-20, 18, -5> 
     point_at <0, -0.5, 4>      
     radius 4                
     tightness 100            
     falloff 15              
}


// right spot
light_source { 
     0                     
     color rgb  0.2       
     spotlight               
     translate < 30, 30, -12> 
     point_at <0, 0, 0>      
     radius 5                
     tightness 50            
     falloff 8              
}

// dim point light
light_source {
     0                  
     color rgb 0.06    
     translate <+ 200, 180, -200>
}
   
       

// ----------------- BASE --------------------

#declare basetex=
texture {
     pigment { 
          marble
          color_map {
               [0.0 rgb 1.0]
               [0.9 rgb 0.9]
          }
          turbulence 1.5
          scale 3
     }
     finish {
          ambient 0.06
     }
}




plane {                       // collect off
     y,
     -1
     
     texture {
          basetex
     }
     
     photons {
          collect off
     }
   
}


box {                         // As part of plane collecting photons             
     <-2.5, -1.05,    -1.1>
     <+3.5, -0.99999, +4.0>
     texture {
          basetex
          // pigment {rgb <0,1,0>}  // to show photon-sensitive part
     }
     
}





//   ------------------------ THE GEM ---------------------------

// Function for the image of the Mayan Date
// http://www.pauahtun.org/Calendar/tools.html
#declare fn_Mayan=
function{
   pigment{
     image_map{
       png "Mayan_Calendar2_bw.png"  // Dec-21-2005, with slight Gauss Blur  
       map_type 0        // planar
       interpolate 4     // 0=none, 1=linear, 2=bilinear, 4=normalized distance
     }
     scale     < 5.4,  2.8, 1>
     translate <-2.7, -1.4, 0>
   }
}

#declare gemmat=
material {
     texture {
          pigment {
               color rgbt 1
          }
          finish {
               diffuse 0.1
               specular 0.9
               roughness 1/400
               
               reflection {
                    0.05,
                    0.35
                    fresnel
                    metallic
               }
               
               conserve_energy
          }
     }
     interior {
          ior 1.765                // Corundum
          fade_power 2       
          fade_distance 0.2      
          fade_color <1, .1, 0>    // almost red
     }
}     





// ------------------- isosurface for the Stela ------------
#declare east=0.15;
#declare north=east;

#declare Stela =
isosurface {
     function {
           - f_superellipsoid(x,y,z, east, north)
           
          /*  It happens that the algorithm used for this function is inside out,
          so if you render function
          {f_superellipsoid(x,y,z,0.5,0.5) } 
          all you see is the outside of your contained_by surface,
          and you may not be aware that there's a superellipsoidal hole buried inside it.
          To turn it right side out, a minus sign must be applied.
          If using a non-zero threshold, it needs to be negated also.*/
          
         
         
         
          + fn_Mayan (x,y,0).red * 0.02 * (z<0.7) 
     //                                 __________    -> no carving at backside
     //   + for carving (- for relief)
          
          
          
          
          
          // for non-glass only:    - f_granite (x,y,z) * 0.025  
       
         
         
     }
     contained_by {
          sphere {
               0,
               2.5
          }
     }
     
     max_gradient 4
     
     material { 
          gemmat
     }
     
     photons {  
          target 1.0
          refraction on
          reflection on
     }
               
               
     // unscaled size = 2x2x2
     scale <0.6, 1, 0.25>
     rotate 15 * y
     translate z

}



// For tests
#declare Dummy = 
superellipsoid {
     <east, north> 
     scale <0.6, 1, 0.25>
     rotate 15 * y
     translate z
     material {gemmat}
     //pigment { rgb <1,1,0> }
}                            




// -------------- and finally:

     //Dummy
     
     Stela